<template>
  <div class="app-container">
    <el-card class="box-card" >
      <el-row>
        <el-divider style="margin-bottom: 10px"><span style="font-size: 40px">发动机返修标记系统</span></el-divider>
      </el-row>
      <el-row style="margin-top: 10px">
        <el-form :model="queryParams.sfcCode" ref="queryForm" :inline="true" label-width="68px" >
          <el-form-item label-width="120" label="发动机号:" prop="orderNo">
            <el-input
              v-model="queryParams.sfcCode"
              placeholder="请输入发动机号"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item style="margin-left: 20px">
            <el-button type="primary" icon="el-icon-refresh" @click="handleQuery">查询</el-button>
            <el-button type="primary" icon="el-icon-scissors" @click="repairProgressHandleQuery">返修进度</el-button>
          </el-form-item>
        </el-form>
      </el-row>
    </el-card>
    <el-row :gutter="0">
      <el-col :span="20">
        <el-card style="margin-top: 10px; height: 490px;" class="box-card">
          <el-table border ref="multipleTable" :data="passingStationCollectionList"  @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column label="工单编号" width="120" align="center" prop="workOrderNo">
            </el-table-column>
            <el-table-column label="总成序列号" width="150" align="center" prop="sfcCode">
            </el-table-column>
            <el-table-column label="产品编号" align="center" prop="productCode">
            </el-table-column>
            <el-table-column label="产线编号" align="center" prop="productionLine">
            </el-table-column>
            <el-table-column label="工位编号" align="center" prop="locationCode">
            </el-table-column>
            <el-table-column label="入站时间" align="center" prop="inboundTime" width="100">
              <template slot-scope="scope">
                <span>{{ parseTime(scope.row.inboundTime, '{y}-{m}-{d}') }}</span>
              </template>
            </el-table-column>
            <el-table-column label="出站时间" align="center" prop="outboundTime" width="100">
              <template slot-scope="scope">
                <span>{{ parseTime(scope.row.outboundTime, '{y}-{m}-{d}') }}</span>
              </template>
            </el-table-column>
            <el-table-column label="是否合格" align="center" prop="outRsSign">
            </el-table-column>
            <el-table-column label="NG原因" align="center" prop="outMsgSign">
            </el-table-column>
            <el-table-column label="采集时间" align="center" prop="collectionTime" width="180">
              <template slot-scope="scope">
                <span>{{ parseTime(scope.row.collectionTime, '{y}-{m}-{d}') }}</span>
              </template>
            </el-table-column>
            <el-table-column label="节拍时间" align="center" prop="beatTime">
            </el-table-column>
          </el-table>
        </el-card>
      </el-col>
      <el-col :span="4">
        <el-card style="margin-top: 10px; min-height: 490px" class="box-card">
          <el-button type="success" @click="selectAll" style="margin-left: 50px;width: 100px;margin-top: 10px">选择所有</el-button>
          <el-button type="success" @click="clearAll" style="margin-left: 50px; width: 100px;margin-top: 10px">取消选择</el-button>
          <el-button type="success" @click="selectUnqualified" style="margin-left: 50px; width: 100px;margin-top: 10px">选择不合格</el-button>
          <el-button type="success" @click="markComplete" style="margin-left: 50px; width: 100px;margin-top: 10px">标记完成</el-button>
          <el-button type="success" @click="repairRecord" style="margin-left: 50px; width: 100px;margin-top: 10px">返修记录</el-button>
          <el-button type="success" @click="operationLog" style="margin-left: 50px; width: 100px;margin-top: 10px">操作日志</el-button>

        </el-card>
      </el-col>
    </el-row>

    <el-dialog v-dialogpop-up :visible.sync="open" width="700px" append-to-body>
      <span slot="title">
        <i class="el-icon-s-order"></i>
        返修进度
      </span>
      <el-table border :data="repairRecordList">
        <el-table-column label="发动机号" width="150" align="center" prop="boxCode" />
        <el-table-column label="工位号" align="center" prop="processesCode" />
        <el-table-column label="返修结果" align="center" prop="repairResults" />
        <el-table-column label="原结果" align="center" prop="originalResult" />
        <el-table-column label="返修时间" align="center" width="160" prop="repairTime" />
      </el-table>
      <div slot="footer" class="dialog-footer">
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>


  </div>
</template>

<script>
import {
  listPassingStationCollection,
  insertRepairRecordByIds
} from "@/api/main/da/passingStationCollection/passingStationCollection";
import {listRepairRecord} from "@/api/main/rm/repairRecord/repairRecord";
export default {
  name: "index",
  dicts: ['sys_normal_disable'],
  data(){
    return{
      // 返修记录表格数据
      repairRecordList: [],
      // 是否显示弹出层
      open: false,
      // 产品过站采集表格数据
      passingStationCollectionList: [],
      // 查询参数
      queryParams: {
        sfcCode: '',
        outRsSign: '',
      },
      ids: [],
      allSelected: false

    }
  },
  mounted() {
    this.getList()
  },
  methods:{
    // 取消按钮
    cancel() {
      this.open = false;
    },
    selectAll(){
      this.passingStationCollectionList.forEach(row => {
        this.$refs.multipleTable.toggleRowSelection(row);
      });
    },
    clearAll(){
      this.$refs.multipleTable.clearSelection();
    },
    selectUnqualified(){
      let outRsSign = this.passingStationCollectionList.filter(row => row.outRsSign === '合格')
      outRsSign.forEach(row => {
        this.$refs.multipleTable.toggleRowSelection(row);
      })
      this.$modal.msgSuccess('选择不合格');
    },
    markComplete(){
      if(this.ids.length === 0){
        this.$modal.msgSuccess('未选择');
      }else {
        this.$modal.msgSuccess('标记完成');
        let queryParams = {
          ids: this.ids
        }
        insertRepairRecordByIds(queryParams).then(response => {

        });
      }
    },
    repairRecord(){
      this.$modal.msgSuccess('返修记录');
    },
    operationLog(){
      this.$modal.msgSuccess('操作日志');
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    repairProgressHandleQuery(){
      this.open = true;
      if(this.queryParams.engineNo === ''||this.queryParams.engineNo=== null){
        this.$modal.msgSuccess('请输入发动机号');
      }else {
        /** 查询返修记录列表 */
        let queryParams = {
          boxCode: this.queryParams.engineNo
        }
        listRepairRecord(queryParams).then(response => {
          this.repairRecordList = response.rows;
        });
      }
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.getList();
    },
    /** 查询产品过站采集列表 */
    getList() {
      listPassingStationCollection(this.queryParams).then(response => {
        this.passingStationCollectionList = response.rows;
        this.total = response.total;
      });
    },

  },
}
</script>

<style scoped>
::v-deep .el-form-item__label{
  font-size: large;
}
::v-deep .el-card__body{
  padding: 15px 20px 0px 20px;
}
</style>
